==> qmmp-plugin-pack-1.4.0.tar.bz2: qmmp-plugin-pack-1.4.0/src/Visual/goom/translations/goom_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>刷新率</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation type="unfinished">25 fps {60 ?}</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>&amp;Full Screen</source>
        <translation>(&amp;F)全螢幕</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="201"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-2.2.2.tar.bz2: qmmp-plugin-pack-2.2.2/src/Visual/goom/translations/goom_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>GoomWidget</name>
    <message>
        <location filename="../goomwidget.cpp" line="137"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="187"/>
        <source>Refresh Rate</source>
        <translation>刷新率</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="190"/>
        <source>60 fps</source>
        <translation>60 幀/秒</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="191"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="192"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="198"/>
        <source>&amp;Show Title</source>
        <translation>(&amp;S)顯示標題</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="202"/>
        <location filename="../goomwidget.cpp" line="204"/>
        <source>&amp;Full Screen</source>
        <translation>(&amp;F)全螢幕</translation>
    </message>
    <message>
        <location filename="../goomwidget.cpp" line="202"/>
        <location filename="../goomwidget.cpp" line="204"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualGoomFactory</name>
    <message>
        <location filename="../visualgoomfactory.cpp" line="30"/>
        <source>Goom</source>
        <translation>Goom 特效</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="49"/>
        <source>About Goom Visual Plugin</source>
        <translation>關於 Goom 視覺特效插件</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="50"/>
        <source>Qmmp Goom Visual Plugin</source>
        <translation>Qmmp Goom 視覺特效插件</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="52"/>
        <source>Based on the source code from the Goom project</source>
        <translation>基於 Goom 專案的原始碼</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="53"/>
        <source>Goom project developers:</source>
        <translation>Goom 專案開發者：</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="54"/>
        <source>Jean-Christophe Hoelt &lt;jeko@ios-software.com&gt;</source>
        <translation>尚 - 克里斯托夫·霍爾特 &lt;jeko@ios-software.com&gt;</translation>
    </message>
    <message>
        <location filename="../visualgoomfactory.cpp" line="55"/>
        <source>Guillaume Borios &lt;gyom@ios-software.com&gt;</source>
        <translation>吉堯姆·博里奧 &lt;gyom@ios-software.com&gt;</translation>
    </message>
</context>
</TS>
